\name{GBSG}
\alias{GBSG}
\non_function{}
\title{ German Breast Cancer Study Group }
\usage{data(GBSG)}
\description{
  A data frame containing the observations from the GBSG study.
}
\format{
  This data frame contains the observations of 686 women:
  \describe{
    \item{id}{patient id 1...686.}
    \item{htreat}{hormonal therapy, a factor at two levels \code{0} (no) and
\code{1} (yes).}
    \item{age}{of the patients in years.}
    \item{menostat}{menopausal status, a factor at two levels \code{1} 
(premenopausal) and \code{2} (postmenopausal).}
    \item{tumsize}{tumor size (in mm).}
    \item{tumgrad}{tumor grade, a ordered factor at levels \code{1 < 2 <
3}.}
    \item{posnodal}{number of positive nodes.}
    \item{prm}{progesterone receptor (in fmol).}
    \item{esm}{estrogen receptor (in fmol).}
    \item{rfst}{recurrence free survival time (in days).}
    \item{cens}{censoring indicator (0- censored, 1- event).}
  }
}
\source{
  \url{http://www.blackwellpublishers.com/rss/Volumes/A162p1.htm}
}
\references{
  M. Schumacher, G. Basert, H. Bojar,  K. Huebner, M. Olschewski, 
  W. Sauerbrei, C. Schmoor, C. Beyerle, R.L.A. Neumann and H.F. Rauschecker
  for the German Breast Cancer Study Group (1994).
  Randomized \eqn{2 \times 2} trial evaluating hormonal treatment
  and the duration of chemotherapy in node-positive breast cancer patients.
  \emph{Journal of Clinical Oncology}, \bold{12}, 2086--2093.

  W. Sauerbrei and P. Royston (1999). Building multivariable prognostic
  and diagnostic models: transformation of the predictors by using 
  fractional polynomials. \emph{Journal of the Royal Statistics Society
  Series A}, Volume \bold{162}(1), 71--94.
}
\examples{
    data(GBSG)
    mfp(Surv(rfst, cens) ~ fp(age, df = 2, select = 0.05)
                 + fp(prm, df = 4, select = 0.05), family = cox, data = GBSG)

}
\keyword{datasets}

\eof
\name{bodyfat}
\alias{bodyfat}
\non_function{}
\title{ percentage of body fat determined by underwater weighing }
\usage{data(GBSG)}
\description{
  A data frame containing the estimates of the percentage of body fat 
  determined by underwater weighing and various body circumference 
  measurements for 252 men.
  
  Source: Roger W. Johnson (1996), ''Fitting Percentage of Body Fat to 
  Simple Body Measurements'', Journal of Statistics Education. 
  Original data are from K. Penrose, A. Nelson, and A. Fisher (1985), 
  ''Generalized Body Composition Prediction Equation for Men Using 
  Simple Measurement Techniques'' (abstract), Medicine and Science in 
  Sports and Exercise, 17(2), 189. 
  
  Data were supplied by Dr. A. Garth Fisher, Human Performance Research 
  Center, Brigham Young University, who gave permission to freely distribute 
  the data and use them for non-commercial purposes. 
  Note, however, that there seem to be a few errors.  
  For instance, body densities for cases 48, 76, and 96 seem to have one digit 
  in error in the two body fat percentage values.  
  Also note a man (case 42) over 200 pounds in weight who is less than 3 feet tall 
  (the height should presumably be 69.5 inches, not 29.5 inches).  
  Percent body fat estimates are truncated to zero when negative (case 182).
}
\format{
  This data frame contains the observations of 252 men:
  \describe{
    \item{case}{Case number.}
    \item{brozek}{Percent body fat using Brozek's equation: 457/Density - 414.2}
    \item{siri}{Percent body fat using Siri's equation: 495/Density - 450}
    \item{density}{Density determined from underwater weighing (\eqn{gm/cm^3}).}
    \item{age}{Age (years).}
    \item{weight}{Weight (lbs).}
    \item{height}{Height (inches).}
    \item{neck}{Neck circumference (cm).}
    \item{chest}{Chest circumference (cm).}
    \item{abdomen}{Abdomen circumference (cm) ''at the umbilicus and level 
                   with the iliac crest''.}
    \item{hip}{Hip circumference (cm).}
    \item{thigh}{Thigh circumference (cm).}
    \item{knee}{Knee circumference (cm).}
    \item{ankle}{Ankle circumference (cm).}
    \item{biceps}{Biceps (extended) circumference (cm).}
    \item{forearm}{Forearm circumference (cm).}
    \item{wrist}{Wrist circumference (cm) ''distal to the styloid processes''.}
  }
}
\source{
  e.g. \url{http://lib.stat.cmu.edu/datasets/bodyfat}
}
\references{
  R.W. Johnson (1996). Fitting percentage of body fat to simple body measurements.
  \emph{Journal of Statistics Education [Online]}, \bold{4(1)}.

  K.W. Penrose, A.G. Nelson, A.G. Fisher (1985). Generalized body composition prediction
           equation for men using simple measurement techniques. \emph{Medicine and Science 
           in Sports and Exercise}, \bold{17}, 189.

  P. Royston, W. Sauerbrei (2004). Improving the robustness of fractional polynomial models 
  by preliminary covariate transformation. Submitted.
}
\examples{
    data(bodyfat)
    bodyfat$height[bodyfat$case==42] <- 69.5   # apparent error
    bodyfat <- bodyfat[-which(bodyfat$case==39),]  # cp. Royston & Sauerbrei, 2004
    mfp(siri ~ fp(age, df = 4, select = 0.1) + fp(weight, df = 4, select = 0.1)
                 + fp(height, df = 4, select = 0.1), family = gaussian, data = bodyfat)
}
\keyword{datasets}

\eof
\name{cox}
\alias{cox}

\title{Family Objects for Cox Proportional Regression Models}

\description{Family objects provide a convenient way to specify the details of
     the models used by functions such as 'glm'. See the documentation
     for 'glm' for details. 
}
   
\usage{cox()}

}

\keyword{ }

\eof
\name{fp}
\alias{fp}

\title{Fractional Polynomial Transformation}

\description{This function defines a fractional polynomial object for an input variable x. 
}
   
\usage{fp(x, df = 4, select = NA, alpha = NA, scale=TRUE)}

\arguments{
 \item{x}{
	input variable.}
 \item{df}{
	degrees of freedom of the FP model. 
	df=4: FP model with maximum permitted degree m=2,
	df=2: FP model with maximum permitted degree m=1,
	df=1: Linear FP model.}
 \item{select}{
	sets the variable selection level for the input variable.}
 \item{alpha}{
	sets the FP selection level for the input variable.}
 \item{scale}{
	use pre-transformation scaling to avoid numerical problems.}
}

\value{}

\examples{
\dontrun{
	fp(x, df = 4, select = 0.05, scale = FALSE)
}
}

\keyword{ }

\eof
\name{mfp}
\alias{mfp}
\title{Fit a Multiple Fractional Polynomial Model} 
\description{
Selects the multiple fractional polynomial (MFP) model which best predicts 
the outcome. The model may be a generalized linear model or a proportional
hazards (Cox) model.
}
\usage{
	mfp(formula, data, family = gaussian, subset, na.action, init, alpha=0.05,
		select=1, verbose=FALSE, x = TRUE, y = TRUE)
}

\arguments{
 \item{formula}{
	a formula object, with the response of the left of a ~ operator, and
	the terms, separated by + operators, on the right. Fractional
	polynomial terms are indicated by fp.  If a Cox PH model is required
	then the outcome should be specified using the Surv() notation used
	by coxph.}
 \item{data}{
	a data frame containing the variables occurring in the formula. If this
	is missing, the variables should be on the search list.}
\item{family}{
	a family object - a list of functions and expressions for defining the
	link and variance functions, initialization and iterative weights.
	Families supported are gaussian, binomial, poisson, Gamma,
	inverse.gaussian and quasi.  Additionally Cox models are specified
	using "cox".}
\item{subset}{
	expression saying which subset of the rows of the data should be used
	in the fit.  All observations are included by default.}
 \item{na.action}{
	function to filter missing data. This is applied to the model.frame
	after any subset argument has been used. The default (with na.fail) is
	to create an error if any missing values are found.}
 \item{init}{
	vector of initial values of the iteration (in Cox models only).}
 \item{alpha}{
	sets the FP selection level for all predictors.  Values for individual
	predictors may be changed via the fp function in the formula.}
 \item{select}{
	sets the variable selection level for all predictors.  Values for
	individual predictors may be changed via the fp function in the formula.}
 \item{verbose}{
	run in verbose mode.}
 \item{x}{
	return the design matrix in the model object?}
 \item{y}{
	return the response in the model object?}
}
\value{
	an object of class \code{mfp} is returned which either inherits from both glm
	and lm or coxph.}
\details{
	The estimation algorithm processes the predictors in turn. Initially, 
	mfp silently arranges the predictors in order of increasing P-value
	(i.e. of decreasing statistical significance) for omitting each predictor
	from the model comprising all the predictors with each term linear. The
	aim is to model relatively important variables before unimportant ones.

	At the initial cycle, the best-fitting FP function for the first predictor
	is determined, with all the other variables assumed linear. The FP
	selection  procedure is described below. The functional form (but NOT the
	estimated regression coefficients) for this predictor is kept, and the 
	process is repeated for the other predictors in turn. The first iteration
	concludes when all the variables have been processed in this way. The next
	cycle is similar, except that the functional forms from the initial cycle
	are retained for all variables excepting the one currently being processed.

	A variable whose functional form is prespecified to be linear (i.e. to 
	have 1 df) is tested only for exclusion within the above procedure when 
	its nominal P-value (selection level) according to select() is less than 1.

	Updating of FP functions and candidate variables continues until the functions
	and variables included in the overall model do not change (convergence).
	Convergence is usually achieved within 1-4 cycles.

	\emph{Model Selection}

	mfp uses a form of backward elimination. It start from a most complex 
	permitted FP model and attempt to simplify it by reducing the df. The 
	selection algorithm is inspired by the so-called "closed test procedure",
	a sequence of tests in each of which the "familywise error rate" or
	P-value is maintained at a prespecified nominal value such as 0.05. 

	The "closed test" algorithm for choosing an FP model with maximum 
	permitted degree m=2 (4 df) for a single continuous predictor, x, is as
	follows:

	1. Inclusion: test the FP in x for possible omission of x (4 df test,
	   significance level determined by select). If x is significant,
	   continue, otherwise drop x from the model.

	2. Non-linearity: test the FP in x against a straight line in x (3 df
	   test, significance level determined by alpha). If significant,
	   continue, otherwise the chosen model is a straight line.

	3. Simplification: test the FP with m=2 (4 df) against the best FP with
	   m=1 (2 df) (2 df test at alpha level). If significant, choose m=2,
	   otherwise choose m=1.

	All significance tests are carried out using an approximate P-value
	calculation based on a difference in deviances (-2 x log likelihood) 
	having a chi-squared or F distribution, depending on the regression in 
	use. Therefore, each of the tests in the procedure maintains a 
	significance level only approximately equal to select. The algorithm is 
	thus not truly a closed procedure. However, for a given significance level
	it does provide some protection against over-fitting, that is against
	choosing over-complex MFP models.}
\section{Side Effects}{
	details are produced on the screen regarding the progress of the 
	backfitting routine. At completion of the algorithm a table is displayed
	showing the final powers selected for each variable along with other
	details.}
\section{Known Bugs}{
	the program can have problems with factor variables. It appears to be
	best to put factors after fp terms in the formula object.
    
	glm models should not be specified without an intercept term as the
	software does not yet allow for that possibility.}
\references{
	Royston, P. and Altman, D. (1994) Regression using fractional polynomials
		of continuous covariates. \emph{Appl Stat.} 3: 429--467.}
    
\seealso{
	mfp.object, fp, plot.fp, glm}

\examples{
	data(GBSG)
	mfp(Surv(rfst, cens) ~ fp(age, df = 4, select = 0.05)
                 + fp(prm, df = 4, select = 0.05), family = cox, data = GBSG)
}

\author{ Gareth Ambler and Axel Benner  }

\keyword{ models }

\eof
\name{mfp.object}
\alias{mfp.object}
\title{Multiple Fractional Polynomial Model Object} 
\description{
Objects returned by fitting fractional polynomial model objects.

These are objects representing fitted \code{mfp} models. 
Class \code{mfp} inherits from either glm or coxph depending on the type of model fitted.
}

\value{
In addition to the standard glm/coxph components the following components are 
included in a \code{mfp} object.

 \item{x}{
	the final FP transformations that are contained in the design matrix x. 
        The predictor "z" with 4 df would have corresponding columns "z.1" and 
        "z.2" in x.}
 \item{powers}{
	a matrix containing the best FP powers for each predictor. If a predictor
	has less than two powers a NA will fill the appropriate cell of the
	matrix.}
 \item{pvalues}{
	a matrix containing the P-values from the closed tests. Briefly p.null is
	the P-value for the test of inclusion (see mfp), p.lin corresponds to
	the test of nonlinearity and p.FP the test of simplification. The best m=1
	power (power2) and best m=2 powers (power4.1 and power4.2) are also given.}
 \item{scale}{
	all predictors are shifted and rescaled before being power transformed if
	nonpositive values are encountered or the range of the predictor is 
	reasonably large. If x' would be used instead of x where
		x' = (x+a)/b
	the parameters a (shift) and b (scale) are contained in the matrix scale.}
 \item{df.initial}{
	a vector containing the degrees of freedom allocated to each predictor.}
 \item{df.final}{
	a vector containing the degrees of freedom of each predictor at
	convergence of the backfitting algorithm.}
 \item{dev}{
	the deviance of the final model.}
 \item{dev.lin}{
	the deviance of the model that has every predictor included with 1 df
	(i.e. linear).}
 \item{dev.null}{
	the deviance of the null model.}
 \item{fptable}{
	the table of the final fp transformations.}
}
  
\seealso{
	mfp, glm.object}

\keyword{ classes }

\eof
\name{plot.mfp}
\alias{plot.mfp}

\title{Plots for mfp objects}

\description{This function draws two plots: (i) the linear predictor function and (ii) partial residuals together with a lowess smooth. 
For Cox models also smoothed martingale based residuals of the null 
model are plotted against the predictor.
}
   
\usage{plot.mfp(x, var=NULL, ...)}

\arguments{
 \item{x}{
	object representing a fitted \code{mfp} model.}
 \item{var}{
	the variable for which plots are desired. 
      By default, plots are produced in turn for each variable of a model.}
 \item{...}{ 
        further arguments.}
}

\value{}

\examples{
	data(GBSG)
	f <- mfp(Surv(rfst, cens) ~ fp(age, df = 4, select = 0.05)
                 + fp(prm, df = 4, select = 0.05), family = cox, data = GBSG)
	par(mfrow=c(2,2), mar=c(4,4,1,1), mgp=c(1.5,0.75,0))
      plot(f, var="age")
}

\keyword{ }

\eof
